nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Mb064bId

Struct Mb064bId 

#[repr(transparent)]
pub struct Mb064bId(pub u32);
Message Buffer 0 ID Register

Tuple Fields

0: u32

Implementations

Source

impl Mb064bId

pub const fn ext(&self) -> u32

Contains extended (LOW word) identifier of message buffer.

pub const fn set_ext(&mut self, val: u32)

Contains extended (LOW word) identifier of message buffer.

pub const fn std(&self) -> u16

Contains standard/extended (HIGH word) identifier of message buffer.

pub const fn set_std(&mut self, val: u16)

Contains standard/extended (HIGH word) identifier of message buffer.

pub const fn prio(&self) -> u8

Local priority. This 3-bit fieldis only used when LPRIO_EN bit is set in MCR and it only makes sense for Tx buffers. These bits are not transmitted. They are appended to the regular ID to define the transmission priority.

pub const fn set_prio(&mut self, val: u8)

Local priority. This 3-bit fieldis only used when LPRIO_EN bit is set in MCR and it only makes sense for Tx buffers. These bits are not transmitted. They are appended to the regular ID to define the transmission priority.